/********************************************************************/
/*                                                                  */
/* Program name: EXPIRED                                            */
/*                                                                  */
/* Description: C program that removes expired messages from all    */
/*              queues on a queue manager                           */
/*                                                                  */
/*                                                                  */
/********************************************************************/
/*                                                                  */
/* Function:                                                        */
/*                                                                  */
/*                                                                  */
/*   EXPIRED is a C program that removes all expired messages from  */
/*   all queues on a queue manager                                  */
/*                                                                  */
/*   If there are no parameters it removes all expired messages     */
/*   from all queues on the default queue manager.                  */
/*   If there is one parameter it uses this as the queue name       */
/*   to remove messages from.                                       */
/*   If there is a second parameter it uses this as the queue       */
/*   manager name.                                                  */
/*   Status:          Version 1 Release 1 Modification 2            */
/*   Date:            4 October 1995                                */
/*   Author:          Sam Garforth (SJG Consulting Ltd)             */
/*   Status:          Version 2 Release 1 Modification 0            */
/*   Date:            7 November 2005                               */
/*   Author:          Sam Garforth (SJG Consulting Ltd)             */
/*    (sam.garforth@bigfoot.com, www.sjg-enterpriseintegration.com) */
/*                                                                  */
/********************************************************************/
#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#ifdef OS2
  /******************************************************************/
  /* for beep                                                       */
  /******************************************************************/
  #define INCL_DOSPROCESS
  #include <os2.h>
#endif

/********************************************************************/
/* includes for MQI                                                 */
/********************************************************************/
#include <cmqc.h>
#include <cmqcfc.h>
void printfmqftstringlist(MQCFSL* pmqcfsl);
void printreas(MQLONG reason);
void rmvexpired(char * thequeue);

 #define PRINTREAS(param)                                           \
    case param:                                                     \
      printf("Reason = %s\n",#param);                               \
      break;

/********************************************************************/
/* global variable                                                  */
/* the command message                                              */
/********************************************************************/
#ifdef OS2
_Packed
#endif
struct cmdmsg2 {
                 MQCFH  pcfheader;
                 MQCFST qname;
                 MQCFIN qtype;
               } cmdmsg = {MQCFH_DEFAULT,
                       MQCFST_DEFAULT,
                       MQCFIN_DEFAULT};
MQCFH    *outmsg;                    /* evtmsg message buffer       */
MQHCONN  Hcon;                       /* connection handle           */


int main(int argc, char **argv)
{
  /******************************************************************/
  /* Declare MQI structures needed                                  */
  /******************************************************************/
  MQOD     od = {MQOD_DEFAULT};      /* Object Descriptor           */
  MQOD     replod = {MQOD_DEFAULT};  /* Object Descriptor           */
  MQMD     md = {MQMD_DEFAULT};      /* Message Descriptor          */
  MQGMO    gmo = {MQGMO_DEFAULT};    /* get message options         */
  MQPMO    pmo = {MQPMO_DEFAULT};    /* get message options         */
  MQMD     PMsgDescriptor= { MQMD_DEFAULT };

  /******************************************************************/
  /* note, uses defaults where it can                               */
  /******************************************************************/
  MQHOBJ   replHobj;                 /* object handle               */
  MQHOBJ   QueueHandle;              /* object handle               */
  MQLONG   O_options;                /* MQOPEN options              */
  MQLONG   C_options;                /* MQCLOSE options             */
  MQLONG   CompCode;                 /* completion code             */
  MQLONG   replOpenCode;             /* MQOPEN completion code      */
  MQLONG   Reason;                   /* reason code                 */
  MQLONG   CReason;                  /* reason code for MQCONN      */
  MQLONG   buflen;                   /* buffer length               */
  MQLONG   outmsglen;                /* message length received     */
  char     QMName[50];               /* queue manager name          */
  char     servstr[100];
  MQCFST  *paras;                    /* the parameters              */
  int      counter;                  /* loop counter                */
  int      flret;                    /* used in flush               */

   /******************************************************************/
   /* See whether they want help                                     */
   /******************************************************************/
   if (argc > 1 && argv[1][0] == '?')
   {
     printf("Usage: expired [Queue] [QMgrName]\n" );
     exit(0);
   }

  /******************************************************************/
  /* Connect to queue manager                                       */
  /******************************************************************/
  QMName[0] = 0;                      /* default queue manager      */
  if (argc > 2)
    strncpy(QMName, argv[2],sizeof(MQCHAR48));
  MQCONN(QMName,                      /* queue manager              */
         &Hcon,                       /* connection handle          */
         &CompCode,                   /* completion code            */
         &CReason);                   /* reason code                */

  /******************************************************************/
  /* report reason and stop if it failed                            */
  /******************************************************************/
  if (CompCode == MQCC_FAILED)
  {
    printf("MQCONN ended with reason code %ld\n", CReason);
    printreas(CReason);
    exit(CReason);
  }

  if (argc > 1)
  {
    rmvexpired(argv[1]);
  }
  else
  {

    /******************************************************************/
    /* Initialize object descriptor for subject queue                 */
    /* Open the reply queue. We have to do this first to get it's     */
    /* name                                                           */
    /******************************************************************/
    strcpy(replod.ObjectName, "SYSTEM.DEFAULT.MODEL.QUEUE");

    /******************************************************************/
    /* Open the replyto queue for input; exclusive or shared.  Use of */
    /* the queue is controlled by the queue definition here           */
    /******************************************************************/
    MQOPEN(Hcon,                        /* connection handle          */
           &replod,                     /* object descriptor for queue*/
           MQOO_INPUT_AS_Q_DEF          /* open queue for input       */
          + MQOO_FAIL_IF_QUIESCING      /* but not if MQM stopping    */
          + MQOO_BROWSE,                /* open options               */
           &replHobj,                   /* object handle              */
           &CompCode,                   /* completion code            */
           &Reason);                    /* reason code                */

    /******************************************************************/
    /* report reason, if any; stop if failed                          */
    /******************************************************************/
    if (Reason != MQRC_NONE)
    {
      printf("MQOPEN (%s) ==> %ld\n", replod.ObjectName, Reason);
      printreas(Reason);
    }

    replOpenCode = CompCode;            /* keep for conditional close */

    /******************************************************************/
    /* run the command server, it shouldn't matter if it's already    */
    /* running                                                        */
    /* There are ways of finding out the default queue mgr name but   */
    /* it's too much hassle                                           */
    /******************************************************************/
    if (strlen(QMName) != 0)
    {
      sprintf(servstr,"strmqcsv %s",QMName);
      system(servstr);
    }
    else
    {
      printf("If this hangs it's because you haven't"
              " started the command server\n");
    }

    /******************************************************************/
    /*                                                                */
    /* First we need a list of queues on the queue manager. To get    */
    /* this we need to put a request to the command server            */
    /*                                                                */
    /******************************************************************/

    /******************************************************************/
    /* Initialize object descriptor for subject queue                 */
    /******************************************************************/
    strcpy(od.ObjectName, "SYSTEM.ADMIN.COMMAND.QUEUE");

    /******************************************************************/
    /* Open the reply queue for input; exclusive or shared.  Use of   */
    /* the queue is controlled by the queue definition here           */
    /******************************************************************/
    O_options = MQOO_OUTPUT             /* open queue for putting     */
          + MQOO_FAIL_IF_QUIESCING;     /* but not if MQM stopping    */
    MQOPEN(Hcon,                        /* connection handle          */
           &od,                         /* object descriptor for queue*/
           O_options,                   /* open options               */
           &QueueHandle,                /* object handle              */
           &CompCode,                   /* completion code            */
           &Reason);                    /* reason code                */

    /******************************************************************/
    /* report reason, if any; stop if failed                          */
    /******************************************************************/
    if (Reason != MQRC_NONE)
    {
      printf("MQOPEN (%s) ==> %ld\n", od.ObjectName, Reason);
      printreas(Reason);
    }

    if (CompCode == MQCC_FAILED)
    {
      /****************************************************************/
      /* get out                                                      */
      /****************************************************************/
      printf( "DO MQDISC\n" );

      MQDISC(&Hcon,
             &CompCode,
             &Reason );

      printf("MQDISC       Reason code    = %d\n", Reason);
      printf("        Hex  Reason code    = %x\n", Reason);
      printf("             Completion code= %d\n", CompCode);
      puts("***\n");
      flret = fflush(stdout);
      puts("Bye...\n\n");
      return 1;
    }

    /******************************************************************/
    /* set the message descriptor to say it's a command message       */
    /******************************************************************/
    memcpy(PMsgDescriptor.Format,
           MQFMT_ADMIN,
           sizeof(PMsgDescriptor.Format));

    memcpy(PMsgDescriptor.ReplyToQ,
           replod.ObjectName,
           sizeof(PMsgDescriptor.ReplyToQ));

    PMsgDescriptor.MsgType = MQMT_REQUEST;

    cmdmsg.pcfheader.Command = MQCMD_INQUIRE_Q_NAMES;
    cmdmsg.pcfheader.ParameterCount = 2;

    /*******************************************************************/
    /* set the parameter to say that we want to know about all queues  */
    /* of the type specified in the other parameter                    */
    /*******************************************************************/
    cmdmsg.qname.Parameter    = MQCA_Q_NAME;
    cmdmsg.qname.String[0]    = '*';
    cmdmsg.qname.StringLength = 1;

    /*******************************************************************/
    /* note that although the length is actually only increased by 1   */
    /* the docs say it should be a multiple of 4                       */
    /*******************************************************************/
    cmdmsg.qname.StrucLength = MQCFST_STRUC_LENGTH_FIXED + 4;

    /*******************************************************************/
    /* set the parameter to say that we want to know about remote      */
    /* queues                                                          */
    /*******************************************************************/
    cmdmsg.qtype.Parameter    = MQIA_Q_TYPE;
    cmdmsg.qtype.Value        = MQQT_LOCAL;

    /******************************************************************/
    /* put the command message                                        */
    /******************************************************************/
    MQPUT(Hcon,
          QueueHandle,
          &PMsgDescriptor,
          &pmo,
          (long int)sizeof(cmdmsg),
          &cmdmsg,
          &CompCode,
          &Reason );

    /*******************************************************************/
    /* if put failed then close, disconnect and exit                   */
    /*******************************************************************/
    if (CompCode)
    {
      printf("MQPUT      Reason code    = %d\n", Reason);
      printf("      Hex  Reason code    = %x\n", Reason);
      printreas(Reason);
      printf("           Completion code= %d\n", CompCode);
      puts("***\n");
      flret = fflush(stdout);

      printf( "DO MQCLOSE -MQPUT Failed\n" );

      MQCLOSE(Hcon,
              &QueueHandle,
              0,
              &CompCode,
              &Reason);

      printf("MQCLOSE      Reason code    = %d\n", Reason);
      printf("        Hex  Reason code    = %x\n", Reason);
      printreas(Reason);
      printf("             Completion code= %d\n", CompCode);
      puts("***\n");
      flret = fflush(stdout);

      printf( "DO MQDISC\n" );

      MQDISC(&Hcon,
             &CompCode,
             &Reason );

      printf("MQDISC       Reason code    = %d\n", Reason);
      printf("        Hex  Reason code    = %x\n", Reason);
      printreas(Reason);
      printf("             Completion code= %d\n", CompCode);
      puts("***\n");
      flret = fflush(stdout);
      puts("Bye...\n\n");
      return 1;
    }

    /******************************************************************/
    /* close the putmsg queue                                         */
    /******************************************************************/
    MQCLOSE(Hcon,                       /* connection handle          */
            &QueueHandle,               /* object handle              */
            0,
            &CompCode,                  /* completion code            */
            &Reason);                   /* reason code                */

    /******************************************************************/
    /* report reason, if any                                          */
    /******************************************************************/
    if (Reason != MQRC_NONE)
    {
      printf("MQCLOSE ==> %ld\n", Reason);
      printreas(Reason);
    }

    /******************************************************************/
    /*   Get messages from the message queue                          */
    /******************************************************************/
    while (CompCode != MQCC_FAILED)
    {
      /****************************************************************/
      /* I don't know how big this message is so just get the         */
      /* descriptor first                                             */
      /****************************************************************/
      gmo.Options = MQGMO_WAIT + MQGMO_LOCK
         + MQGMO_BROWSE_FIRST + MQGMO_ACCEPT_TRUNCATED_MSG;
                                        /* wait for new messages      */
      gmo.WaitInterval = MQWI_UNLIMITED;/* no time limit              */
      buflen = 0;                       /* ammount of message to get  */

      /****************************************************************/
      /* clear selectors to get messages in sequence                  */
      /****************************************************************/
      memcpy(md.MsgId, MQMI_NONE, sizeof(md.MsgId));
      memcpy(md.CorrelId, MQCI_NONE, sizeof(md.CorrelId));

      /****************************************************************/
      /* wait for reply message                                       */
      /****************************************************************/
      MQGET(Hcon,                       /* connection handle          */
            replHobj,                   /* object handle              */
            &md,                        /* message descriptor         */
            &gmo,                       /* get message options        */
            buflen,                     /* buffer length              */
            outmsg,                     /* outmsg message buffer      */
            &outmsglen,                 /* message length             */
            &CompCode,                  /* completion code            */
            &Reason);                   /* reason code                */

      /****************************************************************/
      /* report reason, if any                                        */
      /****************************************************************/
      if (Reason != MQRC_NONE && Reason != MQRC_TRUNCATED_MSG_ACCEPTED)
      {
        printf("MQGET ==> %ld\n", Reason);
        printreas(Reason);
      }
      else
      {
        gmo.Options = MQGMO_NO_WAIT + MQGMO_MSG_UNDER_CURSOR;
        buflen = outmsglen;             /* ammount of message to get  */
        outmsg = malloc(buflen);
        if (outmsg != NULL)
        {
          /************************************************************/
          /* clear selectors to get messages in sequence              */
          /************************************************************/
          memcpy(md.MsgId, MQMI_NONE, sizeof(md.MsgId));
          memcpy(md.CorrelId, MQCI_NONE, sizeof(md.CorrelId));

          /************************************************************/
          /* get the reply message                                    */
          /************************************************************/
          MQGET(Hcon,                     /* connection handle        */
                replHobj,                 /* object handle            */
                &md,                      /* message descriptor       */
                &gmo,                     /* get message options      */
                buflen,                   /* buffer length            */
                outmsg,                   /* outmsg message buffer    */
                &outmsglen,               /* message length           */
                &CompCode,                /* completion code          */
                &Reason);                 /* reason code              */

          /************************************************************/
          /* report reason, if any                                    */
          /************************************************************/
          if (Reason != MQRC_NONE)
          {
            printf("MQGET ==> %ld\n", Reason);
            printreas(Reason);
          }
        }
        else
        {
          CompCode = MQCC_FAILED;
        }
      }
      /****************************************************************/
      /* . . . process each message received                          */
      /****************************************************************/
      if (CompCode != MQCC_FAILED)
      {
        if (outmsglen != buflen)
          printf("DataLength = %ld?\n", outmsglen);
        else
        {
          /************************************************************/
          /* right let's look at the data                             */
          /************************************************************/
          if (outmsg->Type != MQCFT_RESPONSE)
          {
            printf("something's wrong this isn't a response message"
                   " it's type is %ld\n",outmsg->Type);
          }
          else
          {
            printf("reply message arrived\n");
            if (outmsg->StrucLength != MQCFH_STRUC_LENGTH)
            {
              printf("it's the wrong length, %ld\n",outmsg->StrucLength);
            }
            else
            {
              printf("it's the right length\n");
              if (outmsg->Version != MQCFH_VERSION_1)
              {
                printf("it's the wrong version, %ld\n",outmsg->Version);
              }
              else
              {
                printf("it's the right version\n");
                if (outmsg->Command != MQCMD_INQUIRE_Q_NAMES)
                {
                  printf("it's the wrong sort of response message, %ld\n",
                          outmsg->Command);
                }
                else
                {
                  printf("it's the right kind of response message\n");
                  printf("it's sequence number is %ld\n",
                            outmsg->MsgSeqNumber);

                  switch (outmsg->Control)
                  {
                    case MQCFC_LAST:
                      printf("it's control option is MQCFC_LAST\n");
                      /*************************************************/
                      /* to end loop                                   */
                      /*************************************************/
                      CompCode = MQCC_FAILED;
                      break;
                    case MQCFC_NOT_LAST:
                      printf("it's control option is MQCFC_NOT_LAST\n");
                      break;
                    default:
                      printf("it's control option is wrong, %ld\n",
                             outmsg->Control);
                      break;
                  }

                    {
                      if (outmsg->CompCode == MQCC_OK)
                      {
                        printf("CompCode is OK\n");
                      }
                      else
                      {
                        if (outmsg->CompCode == MQCC_WARNING)
                        {
                          printf("CompCode is WARNING\n");
                        }
                        else
                        {
                          if (outmsg->CompCode == MQCC_FAILED)
                          {
                            printf("CompCode is FAILED\n");
                          }
                          else
                          {
                            printf("CompCode is wrong, %ld\n",
                                    outmsg->CompCode);
                          }
                        }
                      }
                      printf("parameter count is %ld\n",
                                    outmsg->ParameterCount);
                      printreas(outmsg->Reason);
                      /************************************************/
                      /* get a pointer to the start of the parameters */
                      /************************************************/
                      paras = (MQCFST *)(outmsg + 1);
                      counter = 1;
                      while (counter <= outmsg->ParameterCount)
                      {
                        switch (paras->Type)
                        {
                          case MQCFT_STRING_LIST:
                            printfmqftstringlist((MQCFSL*)paras);
                            paras = (MQCFST *)((char *)paras
                                                 + paras->StrucLength);
                            break;
                          default:
/*                            printf("unexpected parameter type, %ld\n",
                                   paras->Type);*/
                            counter = outmsg->ParameterCount;
                            break;
                        }
                        counter++;
                      }
                    }
                }
              }
            }
          }
        }   /* end outmsg action             */
        free(outmsg);
      }     /* end process for successful GET */
    }       /* end message processing loop    */

    /******************************************************************/
    /* close the reply queue - if it was opened                       */
    /******************************************************************/
    if (replOpenCode != MQCC_FAILED)
    {
      C_options = 0;                  /* no close options             */
      MQCLOSE(Hcon,                   /* connection handle            */
             &replHobj,               /* object handle                */
             C_options,
             &CompCode,               /* completion code              */
             &Reason);                /* reason code                  */
      /****************************************************************/
      /* report reason, if any                                        */
      /****************************************************************/
      if (Reason != MQRC_NONE)
      {
        printf("MQCLOSE ==> %ld\n", Reason);
        printreas(Reason);
      }
    }
  }

  /******************************************************************/
  /* Disconnect from MQM  (unless previously connected)             */
  /******************************************************************/
  if (CReason != MQRC_ALREADY_CONNECTED)
  {
    MQDISC(&Hcon,                   /* connection handle            */
           &CompCode,               /* completion code              */
           &Reason);                /* reason code                  */
    /****************************************************************/
    /* report reason, if any                                        */
    /****************************************************************/
    if (Reason != MQRC_NONE)
    {
      printf("MQDISC ended with reason code %ld\n", Reason);
      printreas(Reason);
    }
  }
}
/********************************************************************/
/*                                                                  */
/* END OF EXPIRED                                                   */
/*                                                                  */
/********************************************************************/

#define PRINTPARAM(param)                                       \
   case param:                                                     \
     printf("%s\n",#param);                                        \
     break;

void printfmqftstringlist(MQCFSL* pmqcfsl)
{
  MQLONG numqueues;
  char * thequeue;

  switch (pmqcfsl->Parameter)
  {
    PRINTPARAM(MQCA_ALTERATION_DATE       )
    PRINTPARAM(MQCA_ALTERATION_TIME       )
    PRINTPARAM(MQCA_APPL_ID               )
    PRINTPARAM(MQCA_AUTH_INFO_CONN_NAME   )
    PRINTPARAM(MQCA_AUTH_INFO_DESC        )
    PRINTPARAM(MQCA_AUTH_INFO_NAME        )
    PRINTPARAM(MQCA_AUTO_REORG_CATALOG    )
    PRINTPARAM(MQCA_AUTO_REORG_START_TIME )
    PRINTPARAM(MQCA_BACKOUT_REQ_Q_NAME    )
    PRINTPARAM(MQCA_BASE_Q_NAME           )
    PRINTPARAM(MQCA_BATCH_INTERFACE_ID    )
    PRINTPARAM(MQCA_CF_STRUC_DESC         )
    PRINTPARAM(MQCA_CF_STRUC_NAME         )
    PRINTPARAM(MQCA_CHANNEL_AUTO_DEF_EXIT )
    PRINTPARAM(MQCA_CHINIT_SERVICE_PARM   )
    PRINTPARAM(MQCA_CICS_FILE_NAME        )
    PRINTPARAM(MQCA_CLUSTER_DATE          )
    PRINTPARAM(MQCA_CLUSTER_NAME          )
    PRINTPARAM(MQCA_CLUSTER_NAMELIST      )
    PRINTPARAM(MQCA_CLUSTER_Q_MGR_NAME    )
    PRINTPARAM(MQCA_CLUSTER_TIME          )
    PRINTPARAM(MQCA_CLUSTER_WORKLOAD_DATA )
    PRINTPARAM(MQCA_CLUSTER_WORKLOAD_EXIT )
    PRINTPARAM(MQCA_COMMAND_INPUT_Q_NAME  )
    PRINTPARAM(MQCA_COMMAND_REPLY_Q_NAME  )
    PRINTPARAM(MQCA_CREATION_DATE         )
    PRINTPARAM(MQCA_CREATION_TIME         )
    PRINTPARAM(MQCA_DEAD_LETTER_Q_NAME    )
    PRINTPARAM(MQCA_DEF_XMIT_Q_NAME       )
    PRINTPARAM(MQCA_DNS_GROUP             )
    PRINTPARAM(MQCA_ENV_DATA              )
    PRINTPARAM(MQCA_IGQ_USER_ID           )
    PRINTPARAM(MQCA_INITIATION_Q_NAME     )
    PRINTPARAM(MQCA_LDAP_PASSWORD         )
    PRINTPARAM(MQCA_LDAP_USER_NAME        )
    PRINTPARAM(MQCA_LU_GROUP_NAME         )
    PRINTPARAM(MQCA_LU_NAME               )
    PRINTPARAM(MQCA_LU62_ARM_SUFFIX       )
    PRINTPARAM(MQCA_MONITOR_Q_NAME        )
    PRINTPARAM(MQCA_NAMELIST_DESC         )
    PRINTPARAM(MQCA_NAMELIST_NAME         )
    PRINTPARAM(MQCA_NAMES                 )
    PRINTPARAM(MQCA_PASS_TICKET_APPL      )
    PRINTPARAM(MQCA_PROCESS_DESC          )
    PRINTPARAM(MQCA_PROCESS_NAME          )
    PRINTPARAM(MQCA_Q_DESC                )
    PRINTPARAM(MQCA_Q_MGR_DESC            )
    PRINTPARAM(MQCA_Q_MGR_IDENTIFIER      )
    PRINTPARAM(MQCA_Q_MGR_NAME            )
    PRINTPARAM(MQCA_Q_NAME                )
    PRINTPARAM(MQCA_QSG_NAME              )
    PRINTPARAM(MQCA_REMOTE_Q_MGR_NAME     )
    PRINTPARAM(MQCA_REMOTE_Q_NAME         )
    PRINTPARAM(MQCA_REPOSITORY_NAME       )
    PRINTPARAM(MQCA_REPOSITORY_NAMELIST   )
    PRINTPARAM(MQCA_SERVICE_DESC          )
    PRINTPARAM(MQCA_SERVICE_NAME          )
    PRINTPARAM(MQCA_SERVICE_START_ARGS    )
    PRINTPARAM(MQCA_SERVICE_START_COMMAND )
    PRINTPARAM(MQCA_SERVICE_STOP_ARGS     )
    PRINTPARAM(MQCA_SERVICE_STOP_COMMAND  )
    PRINTPARAM(MQCA_STDERR_DESTINATION    )
    PRINTPARAM(MQCA_STDOUT_DESTINATION    )
    PRINTPARAM(MQCA_SSL_CRL_NAMELIST      )
    PRINTPARAM(MQCA_SSL_CRYPTO_HARDWARE   )
    PRINTPARAM(MQCA_SSL_KEY_LIBRARY       )
    PRINTPARAM(MQCA_SSL_KEY_MEMBER        )
    PRINTPARAM(MQCA_SSL_KEY_REPOSITORY    )
    PRINTPARAM(MQCA_STORAGE_CLASS         )
    PRINTPARAM(MQCA_STORAGE_CLASS_DESC    )
    PRINTPARAM(MQCA_SYSTEM_LOG_Q_NAME     )
    PRINTPARAM(MQCA_TCP_NAME              )
    PRINTPARAM(MQCA_TPIPE_NAME            )
    PRINTPARAM(MQCA_TRIGGER_CHANNEL_NAME  )
    PRINTPARAM(MQCA_TRIGGER_DATA          )
    PRINTPARAM(MQCA_TRIGGER_PROGRAM_NAME  )
    PRINTPARAM(MQCA_TRIGGER_TERM_ID       )
    PRINTPARAM(MQCA_TRIGGER_TRANS_ID      )
    PRINTPARAM(MQCA_USER_DATA             )
    PRINTPARAM(MQCA_USER_LIST             )
    PRINTPARAM(MQCA_XCF_GROUP_NAME        )
    PRINTPARAM(MQCA_XCF_MEMBER_NAME       )
    PRINTPARAM(MQCA_XMIT_Q_NAME           )
    PRINTPARAM(MQCAMO_CLOSE_DATE               )
    PRINTPARAM(MQCAMO_CLOSE_TIME               )
    PRINTPARAM(MQCAMO_CONN_DATE                )
    PRINTPARAM(MQCAMO_CONN_TIME                )
    PRINTPARAM(MQCAMO_DISC_DATE                )
    PRINTPARAM(MQCAMO_DISC_TIME                )
    PRINTPARAM(MQCAMO_END_DATE                 )
    PRINTPARAM(MQCAMO_END_TIME                 )
    PRINTPARAM(MQCAMO_OPEN_DATE                )
    PRINTPARAM(MQCAMO_OPEN_TIME                )
    PRINTPARAM(MQCAMO_START_DATE               )
    PRINTPARAM(MQCAMO_START_TIME               )
    PRINTPARAM(MQCACF_FROM_Q_NAME              )
    PRINTPARAM(MQCACF_TO_Q_NAME                )
    PRINTPARAM(MQCACF_FROM_PROCESS_NAME        )
    PRINTPARAM(MQCACF_TO_PROCESS_NAME          )
    PRINTPARAM(MQCACF_FROM_NAMELIST_NAME       )
    PRINTPARAM(MQCACF_TO_NAMELIST_NAME         )
    PRINTPARAM(MQCACF_FROM_CHANNEL_NAME        )
    PRINTPARAM(MQCACF_TO_CHANNEL_NAME          )
    PRINTPARAM(MQCACF_FROM_AUTH_INFO_NAME      )
    PRINTPARAM(MQCACF_TO_AUTH_INFO_NAME        )
    PRINTPARAM(MQCACF_Q_NAMES                  )
    PRINTPARAM(MQCACF_PROCESS_NAMES            )
    PRINTPARAM(MQCACF_NAMELIST_NAMES           )
    PRINTPARAM(MQCACF_ESCAPE_TEXT              )
    PRINTPARAM(MQCACF_LOCAL_Q_NAMES            )
    PRINTPARAM(MQCACF_MODEL_Q_NAMES            )
    PRINTPARAM(MQCACF_ALIAS_Q_NAMES            )
    PRINTPARAM(MQCACF_REMOTE_Q_NAMES           )
    PRINTPARAM(MQCACF_SENDER_CHANNEL_NAMES     )
    PRINTPARAM(MQCACF_SERVER_CHANNEL_NAMES     )
    PRINTPARAM(MQCACF_REQUESTER_CHANNEL_NAMES  )
    PRINTPARAM(MQCACF_RECEIVER_CHANNEL_NAMES   )
    PRINTPARAM(MQCACF_OBJECT_Q_MGR_NAME        )
    PRINTPARAM(MQCACF_APPL_NAME                )
    PRINTPARAM(MQCACF_USER_IDENTIFIER          )
    PRINTPARAM(MQCACF_AUX_ERROR_DATA_STR_1     )
    PRINTPARAM(MQCACF_AUX_ERROR_DATA_STR_2     )
    PRINTPARAM(MQCACF_AUX_ERROR_DATA_STR_3     )
    PRINTPARAM(MQCACF_BRIDGE_NAME              )
    PRINTPARAM(MQCACF_STREAM_NAME              )
    PRINTPARAM(MQCACF_TOPIC                    )
    PRINTPARAM(MQCACF_PARENT_Q_MGR_NAME        )
    PRINTPARAM(MQCACF_CORREL_ID                )
    PRINTPARAM(MQCACF_PUBLISH_TIMESTAMP        )
    PRINTPARAM(MQCACF_STRING_DATA              )
    PRINTPARAM(MQCACF_SUPPORTED_STREAM_NAME    )
    PRINTPARAM(MQCACF_REG_TOPIC                )
    PRINTPARAM(MQCACF_REG_TIME                 )
    PRINTPARAM(MQCACF_REG_USER_ID              )
    PRINTPARAM(MQCACF_CHILD_Q_MGR_NAME         )
    PRINTPARAM(MQCACF_REG_STREAM_NAME          )
    PRINTPARAM(MQCACF_REG_Q_MGR_NAME           )
    PRINTPARAM(MQCACF_REG_Q_NAME               )
    PRINTPARAM(MQCACF_REG_CORREL_ID            )
    PRINTPARAM(MQCACF_EVENT_USER_ID            )
    PRINTPARAM(MQCACF_OBJECT_NAME              )
    PRINTPARAM(MQCACF_EVENT_Q_MGR              )
    PRINTPARAM(MQCACF_AUTH_INFO_NAMES          )
    PRINTPARAM(MQCACF_EVENT_APPL_IDENTITY      )
    PRINTPARAM(MQCACF_EVENT_APPL_NAME          )
    PRINTPARAM(MQCACF_EVENT_APPL_ORIGIN        )
    PRINTPARAM(MQCACF_SUBSCRIPTION_NAME        )
    PRINTPARAM(MQCACF_REG_SUB_NAME             )
    PRINTPARAM(MQCACF_SUBSCRIPTION_IDENTITY    )
    PRINTPARAM(MQCACF_REG_SUB_IDENTITY         )
    PRINTPARAM(MQCACF_SUBSCRIPTION_USER_DATA   )
    PRINTPARAM(MQCACF_REG_SUB_USER_DATA        )
    PRINTPARAM(MQCACF_APPL_TAG                 )
    PRINTPARAM(MQCACF_DATA_SET_NAME            )
    PRINTPARAM(MQCACF_UOW_START_DATE           )
    PRINTPARAM(MQCACF_UOW_START_TIME           )
    PRINTPARAM(MQCACF_UOW_LOG_START_DATE       )
    PRINTPARAM(MQCACF_UOW_LOG_START_TIME       )
    PRINTPARAM(MQCACF_UOW_LOG_EXTENT_NAME      )
    PRINTPARAM(MQCACF_PRINCIPAL_ENTITY_NAMES   )
    PRINTPARAM(MQCACF_GROUP_ENTITY_NAMES       )
    PRINTPARAM(MQCACF_AUTH_PROFILE_NAME        )
    PRINTPARAM(MQCACF_ENTITY_NAME              )
    PRINTPARAM(MQCACF_SERVICE_COMPONENT        )
    PRINTPARAM(MQCACF_RESPONSE_Q_MGR_NAME      )
    PRINTPARAM(MQCACF_CURRENT_LOG_EXTENT_NAME  )
    PRINTPARAM(MQCACF_RESTART_LOG_EXTENT_NAME  )
    PRINTPARAM(MQCACF_MEDIA_LOG_EXTENT_NAME    )
    PRINTPARAM(MQCACF_LOG_PATH                 )
    PRINTPARAM(MQCACF_COMMAND_MQSC             )
    PRINTPARAM(MQCACF_Q_MGR_CPF                )
    PRINTPARAM(MQCACF_USAGE_LOG_RBA            )
    PRINTPARAM(MQCACF_USAGE_LOG_LRSN           )
    PRINTPARAM(MQCACF_COMMAND_SCOPE            )
    PRINTPARAM(MQCACF_ASID                     )
    PRINTPARAM(MQCACF_PSB_NAME                 )
    PRINTPARAM(MQCACF_PST_ID                   )
    PRINTPARAM(MQCACF_TASK_NUMBER              )
    PRINTPARAM(MQCACF_TRANSACTION_ID           )
    PRINTPARAM(MQCACF_Q_MGR_UOW_ID             )
    PRINTPARAM(MQCACF_ORIGIN_NAME              )
    PRINTPARAM(MQCACF_ENV_INFO                 )
    PRINTPARAM(MQCACF_SECURITY_PROFILE         )
    PRINTPARAM(MQCACF_CONFIGURATION_DATE       )
    PRINTPARAM(MQCACF_CONFIGURATION_TIME       )
    PRINTPARAM(MQCACF_FROM_CF_STRUC_NAME       )
    PRINTPARAM(MQCACF_TO_CF_STRUC_NAME         )
    PRINTPARAM(MQCACF_CF_STRUC_NAMES           )
    PRINTPARAM(MQCACF_FAIL_DATE                )
    PRINTPARAM(MQCACF_FAIL_TIME                )
    PRINTPARAM(MQCACF_BACKUP_DATE              )
    PRINTPARAM(MQCACF_BACKUP_TIME              )
    PRINTPARAM(MQCACF_SYSTEM_NAME              )
    PRINTPARAM(MQCACF_CF_STRUC_BACKUP_START    )
    PRINTPARAM(MQCACF_CF_STRUC_BACKUP_END      )
    PRINTPARAM(MQCACF_CF_STRUC_LOG_Q_MGRS      )
    PRINTPARAM(MQCACF_FROM_STORAGE_CLASS       )
    PRINTPARAM(MQCACF_TO_STORAGE_CLASS         )
    PRINTPARAM(MQCACF_STORAGE_CLASS_NAMES      )
    PRINTPARAM(MQCACF_DSG_NAME                 )
    PRINTPARAM(MQCACF_DB2_NAME                 )
    PRINTPARAM(MQCACF_SYSP_CMD_USER_ID         )
    PRINTPARAM(MQCACF_SYSP_OTMA_GROUP          )
    PRINTPARAM(MQCACF_SYSP_OTMA_MEMBER         )
    PRINTPARAM(MQCACF_SYSP_OTMA_DRU_EXIT       )
    PRINTPARAM(MQCACF_SYSP_OTMA_TPIPE_PFX      )
    PRINTPARAM(MQCACF_SYSP_ARCHIVE_PFX1        )
    PRINTPARAM(MQCACF_SYSP_ARCHIVE_UNIT1       )
    PRINTPARAM(MQCACF_SYSP_LOG_CORREL_ID       )
    PRINTPARAM(MQCACF_SYSP_UNIT_VOLSER         )
    PRINTPARAM(MQCACF_SYSP_Q_MGR_TIME          )
    PRINTPARAM(MQCACF_SYSP_Q_MGR_DATE          )
    PRINTPARAM(MQCACF_SYSP_Q_MGR_RBA           )
    PRINTPARAM(MQCACF_SYSP_LOG_RBA             )
    PRINTPARAM(MQCACF_SYSP_SERVICE             )
    PRINTPARAM(MQCACF_FROM_LISTENER_NAME       )
    PRINTPARAM(MQCACF_TO_LISTENER_NAME         )
    PRINTPARAM(MQCACF_FROM_SERVICE_NAME        )
    PRINTPARAM(MQCACF_TO_SERVICE_NAME          )
    PRINTPARAM(MQCACF_LAST_PUT_DATE            )
    PRINTPARAM(MQCACF_LAST_PUT_TIME            )
    PRINTPARAM(MQCACF_LAST_GET_DATE            )
    PRINTPARAM(MQCACF_LAST_GET_TIME            )
    PRINTPARAM(MQCACF_OPERATION_DATE           )
    PRINTPARAM(MQCACF_OPERATION_TIME           )
    PRINTPARAM(MQCACF_ACTIVITY_DESC            )
    PRINTPARAM(MQCACF_APPL_IDENTITY_DATA       )
    PRINTPARAM(MQCACF_APPL_ORIGIN_DATA         )
    PRINTPARAM(MQCACF_PUT_DATE                 )
    PRINTPARAM(MQCACF_PUT_TIME                 )
    PRINTPARAM(MQCACF_REPLY_TO_Q               )
    PRINTPARAM(MQCACF_REPLY_TO_Q_MGR           )
    PRINTPARAM(MQCACF_RESOLVED_Q_NAME          )
    PRINTPARAM(MQCACF_STRUC_ID                 )
    PRINTPARAM(MQCACF_VALUE_NAME               )
    PRINTPARAM(MQCACF_SERVICE_START_DATE       )
    PRINTPARAM(MQCACF_SERVICE_START_TIME       )
    PRINTPARAM(MQCACF_SYSP_OFFLINE_RBA         )
    PRINTPARAM(MQCACF_SYSP_ARCHIVE_PFX2        )
    PRINTPARAM(MQCACF_SYSP_ARCHIVE_UNIT2       )
    PRINTPARAM(MQCACH_CHANNEL_NAME             )
    PRINTPARAM(MQCACH_DESC                     )
    PRINTPARAM(MQCACH_MODE_NAME                )
    PRINTPARAM(MQCACH_TP_NAME                  )
    PRINTPARAM(MQCACH_XMIT_Q_NAME              )
    PRINTPARAM(MQCACH_CONNECTION_NAME          )
    PRINTPARAM(MQCACH_MCA_NAME                 )
    PRINTPARAM(MQCACH_SEC_EXIT_NAME            )
    PRINTPARAM(MQCACH_MSG_EXIT_NAME            )
    PRINTPARAM(MQCACH_SEND_EXIT_NAME           )
    PRINTPARAM(MQCACH_RCV_EXIT_NAME            )
    PRINTPARAM(MQCACH_CHANNEL_NAMES            )
    PRINTPARAM(MQCACH_SEC_EXIT_USER_DATA       )
    PRINTPARAM(MQCACH_MSG_EXIT_USER_DATA       )
    PRINTPARAM(MQCACH_SEND_EXIT_USER_DATA      )
    PRINTPARAM(MQCACH_RCV_EXIT_USER_DATA       )
    PRINTPARAM(MQCACH_USER_ID                  )
    PRINTPARAM(MQCACH_PASSWORD                 )
    PRINTPARAM(MQCACH_LOCAL_ADDRESS            )
    PRINTPARAM(MQCACH_LOCAL_NAME               )
    PRINTPARAM(MQCACH_LAST_MSG_TIME            )
    PRINTPARAM(MQCACH_LAST_MSG_DATE            )
    PRINTPARAM(MQCACH_MCA_USER_ID              )
    PRINTPARAM(MQCACH_CHANNEL_START_TIME       )
    PRINTPARAM(MQCACH_CHANNEL_START_DATE       )
    PRINTPARAM(MQCACH_MCA_JOB_NAME             )
    PRINTPARAM(MQCACH_LAST_LUWID               )
    PRINTPARAM(MQCACH_CURRENT_LUWID            )
    PRINTPARAM(MQCACH_FORMAT_NAME              )
    PRINTPARAM(MQCACH_MR_EXIT_NAME             )
    PRINTPARAM(MQCACH_MR_EXIT_USER_DATA        )
    PRINTPARAM(MQCACH_SSL_CIPHER_SPEC          )
    PRINTPARAM(MQCACH_SSL_PEER_NAME            )
    PRINTPARAM(MQCACH_SSL_HANDSHAKE_STAGE      )
    PRINTPARAM(MQCACH_SSL_SHORT_PEER_NAME      )
    PRINTPARAM(MQCACH_REMOTE_APPL_TAG          )
    PRINTPARAM(MQCACH_SSL_CERT_USER_ID         )
    PRINTPARAM(MQCACH_SSL_CERT_ISSUER_NAME     )
    PRINTPARAM(MQCACH_LU_NAME                  )
    PRINTPARAM(MQCACH_IP_ADDRESS               )
    PRINTPARAM(MQCACH_TCP_NAME                 )
    PRINTPARAM(MQCACH_LISTENER_NAME            )
    PRINTPARAM(MQCACH_LISTENER_DESC            )
    PRINTPARAM(MQCACH_LISTENER_START_DATE      )
    PRINTPARAM(MQCACH_LISTENER_START_TIME      )
    PRINTPARAM(MQCACH_SSL_KEY_RESET_DATE       )
    PRINTPARAM(MQCACH_SSL_KEY_RESET_TIME       )
    default:
      printf("Invalid parameter, %ld\n",pmqcfsl->Parameter);
      break;
  }
  printf("There are %ld strings\n",pmqcfsl->Count);
  if (pmqcfsl->Count != 0)
  {
    thequeue = malloc(pmqcfsl->StringLength + 1);
    if (thequeue != NULL)
    {
      for (numqueues = 0; numqueues < pmqcfsl->Count; numqueues++)
      {
        strncpy(thequeue,
                pmqcfsl->Strings + (numqueues * pmqcfsl->StringLength),
                pmqcfsl->StringLength);
        printf("%s\n",thequeue);
        rmvexpired(thequeue);
      }
    }
  }
}


/*********************************************************************/
/* Print the reason code                                             */
/*********************************************************************/
void printreas(MQLONG reason)
{
  switch (reason)
  {
    PRINTREAS(MQRCCF_CFH_TYPE_ERROR             )
    PRINTREAS(MQRCCF_CFH_LENGTH_ERROR           )
    PRINTREAS(MQRCCF_CFH_VERSION_ERROR          )
    PRINTREAS(MQRCCF_CFH_MSG_SEQ_NUMBER_ERR     )
    PRINTREAS(MQRCCF_CFH_CONTROL_ERROR          )
    PRINTREAS(MQRCCF_CFH_PARM_COUNT_ERROR       )
    PRINTREAS(MQRCCF_CFH_COMMAND_ERROR          )
    PRINTREAS(MQRCCF_COMMAND_FAILED             )
    PRINTREAS(MQRCCF_CFIN_LENGTH_ERROR          )
    PRINTREAS(MQRCCF_CFST_LENGTH_ERROR          )
    PRINTREAS(MQRCCF_CFST_STRING_LENGTH_ERR     )
    PRINTREAS(MQRCCF_FORCE_VALUE_ERROR          )
    PRINTREAS(MQRCCF_STRUCTURE_TYPE_ERROR       )
    PRINTREAS(MQRCCF_CFIN_PARM_ID_ERROR         )
    PRINTREAS(MQRCCF_CFST_PARM_ID_ERROR         )
    PRINTREAS(MQRCCF_MSG_LENGTH_ERROR           )
    PRINTREAS(MQRCCF_CFIN_DUPLICATE_PARM        )
    PRINTREAS(MQRCCF_CFST_DUPLICATE_PARM        )
    PRINTREAS(MQRCCF_PARM_COUNT_TOO_SMALL       )
    PRINTREAS(MQRCCF_PARM_COUNT_TOO_BIG         )
    PRINTREAS(MQRCCF_Q_ALREADY_IN_CELL          )
    PRINTREAS(MQRCCF_Q_TYPE_ERROR               )
    PRINTREAS(MQRCCF_MD_FORMAT_ERROR            )
    PRINTREAS(MQRCCF_CFSL_LENGTH_ERROR          )
    PRINTREAS(MQRCCF_REPLACE_VALUE_ERROR        )
    PRINTREAS(MQRCCF_CFIL_DUPLICATE_VALUE       )
    PRINTREAS(MQRCCF_CFIL_COUNT_ERROR           )
    PRINTREAS(MQRCCF_CFIL_LENGTH_ERROR          )
    PRINTREAS(MQRCCF_MODE_VALUE_ERROR           )
    PRINTREAS(MQRCCF_MSG_SEQ_NUMBER_ERROR       )
    PRINTREAS(MQRCCF_PING_DATA_COUNT_ERROR      )
    PRINTREAS(MQRCCF_PING_DATA_COMPARE_ERROR    )
    PRINTREAS(MQRCCF_CFSL_PARM_ID_ERROR         )
    PRINTREAS(MQRCCF_CHANNEL_TYPE_ERROR         )
    PRINTREAS(MQRCCF_PARM_SEQUENCE_ERROR        )
    PRINTREAS(MQRCCF_XMIT_PROTOCOL_TYPE_ERR     )
    PRINTREAS(MQRCCF_BATCH_SIZE_ERROR           )
    PRINTREAS(MQRCCF_DISC_INT_ERROR             )
    PRINTREAS(MQRCCF_SHORT_RETRY_ERROR          )
    PRINTREAS(MQRCCF_SHORT_TIMER_ERROR          )
    PRINTREAS(MQRCCF_LONG_RETRY_ERROR           )
    PRINTREAS(MQRCCF_LONG_TIMER_ERROR           )
    PRINTREAS(MQRCCF_SEQ_NUMBER_WRAP_ERROR      )
    PRINTREAS(MQRCCF_MAX_MSG_LENGTH_ERROR       )
    PRINTREAS(MQRCCF_PUT_AUTH_ERROR             )
    PRINTREAS(MQRCCF_PURGE_VALUE_ERROR          )
    PRINTREAS(MQRCCF_CFIL_PARM_ID_ERROR         )
    PRINTREAS(MQRCCF_MSG_TRUNCATED              )
    PRINTREAS(MQRCCF_CCSID_ERROR                )
    PRINTREAS(MQRCCF_ENCODING_ERROR             )
    PRINTREAS(MQRCCF_QUEUES_VALUE_ERROR         )
    PRINTREAS(MQRCCF_DATA_CONV_VALUE_ERROR      )
    PRINTREAS(MQRCCF_INDOUBT_VALUE_ERROR        )
    PRINTREAS(MQRCCF_ESCAPE_TYPE_ERROR          )
    PRINTREAS(MQRCCF_REPOS_VALUE_ERROR          )
    PRINTREAS(MQRCCF_CHANNEL_TABLE_ERROR        )
    PRINTREAS(MQRCCF_MCA_TYPE_ERROR             )
    PRINTREAS(MQRCCF_CHL_INST_TYPE_ERROR        )
    PRINTREAS(MQRCCF_CHL_STATUS_NOT_FOUND       )
    PRINTREAS(MQRCCF_CFSL_DUPLICATE_PARM        )
    PRINTREAS(MQRCCF_CFSL_TOTAL_LENGTH_ERROR    )
    PRINTREAS(MQRCCF_CFSL_COUNT_ERROR           )
    PRINTREAS(MQRCCF_CFSL_STRING_LENGTH_ERR     )
    PRINTREAS(MQRCCF_BROKER_DELETED             )
    PRINTREAS(MQRCCF_STREAM_ERROR               )
    PRINTREAS(MQRCCF_TOPIC_ERROR                )
    PRINTREAS(MQRCCF_NOT_REGISTERED             )
    PRINTREAS(MQRCCF_Q_MGR_NAME_ERROR           )
    PRINTREAS(MQRCCF_INCORRECT_STREAM           )
    PRINTREAS(MQRCCF_Q_NAME_ERROR               )
    PRINTREAS(MQRCCF_NO_RETAINED_MSG            )
    PRINTREAS(MQRCCF_DUPLICATE_IDENTITY         )
    PRINTREAS(MQRCCF_INCORRECT_Q                )
    PRINTREAS(MQRCCF_CORREL_ID_ERROR            )
    PRINTREAS(MQRCCF_NOT_AUTHORIZED             )
    PRINTREAS(MQRCCF_UNKNOWN_STREAM             )
    PRINTREAS(MQRCCF_REG_OPTIONS_ERROR          )
    PRINTREAS(MQRCCF_PUB_OPTIONS_ERROR          )
    PRINTREAS(MQRCCF_UNKNOWN_BROKER             )
    PRINTREAS(MQRCCF_Q_MGR_CCSID_ERROR          )
    PRINTREAS(MQRCCF_DEL_OPTIONS_ERROR          )
    PRINTREAS(MQRCCF_CLUSTER_NAME_CONFLICT      )
    PRINTREAS(MQRCCF_REPOS_NAME_CONFLICT        )
    PRINTREAS(MQRCCF_CLUSTER_Q_USAGE_ERROR      )
    PRINTREAS(MQRCCF_ACTION_VALUE_ERROR         )
    PRINTREAS(MQRCCF_COMMS_LIBRARY_ERROR        )
    PRINTREAS(MQRCCF_NETBIOS_NAME_ERROR         )
    PRINTREAS(MQRCCF_BROKER_COMMAND_FAILED      )
    PRINTREAS(MQRCCF_CFST_CONFLICTING_PARM      )
    PRINTREAS(MQRCCF_PATH_NOT_VALID             )
    PRINTREAS(MQRCCF_PARM_SYNTAX_ERROR          )
    PRINTREAS(MQRCCF_PWD_LENGTH_ERROR           )
    PRINTREAS(MQRCCF_FILTER_ERROR               )
    PRINTREAS(MQRCCF_WRONG_USER                 )
    PRINTREAS(MQRCCF_DUPLICATE_SUBSCRIPTION     )
    PRINTREAS(MQRCCF_SUB_NAME_ERROR             )
    PRINTREAS(MQRCCF_SUB_IDENTITY_ERROR         )
    PRINTREAS(MQRCCF_SUBSCRIPTION_IN_USE        )
    PRINTREAS(MQRCCF_SUBSCRIPTION_LOCKED        )
    PRINTREAS(MQRCCF_ALREADY_JOINED             )
    PRINTREAS(MQRCCF_OBJECT_IN_USE              )
    PRINTREAS(MQRCCF_UNKNOWN_FILE_NAME          )
    PRINTREAS(MQRCCF_FILE_NOT_AVAILABLE         )
    PRINTREAS(MQRCCF_DISC_RETRY_ERROR           )
    PRINTREAS(MQRCCF_ALLOC_RETRY_ERROR          )
    PRINTREAS(MQRCCF_ALLOC_SLOW_TIMER_ERROR     )
    PRINTREAS(MQRCCF_ALLOC_FAST_TIMER_ERROR     )
    PRINTREAS(MQRCCF_PORT_NUMBER_ERROR          )
    PRINTREAS(MQRCCF_CHL_SYSTEM_NOT_ACTIVE      )
    PRINTREAS(MQRCCF_ENTITY_NAME_MISSING        )
    PRINTREAS(MQRCCF_PROFILE_NAME_ERROR         )
    PRINTREAS(MQRCCF_AUTH_VALUE_ERROR           )
    PRINTREAS(MQRCCF_AUTH_VALUE_MISSING         )
    PRINTREAS(MQRCCF_OBJECT_TYPE_MISSING        )
    PRINTREAS(MQRCCF_CONNECTION_ID_ERROR        )
    PRINTREAS(MQRCCF_LOG_TYPE_ERROR             )
    PRINTREAS(MQRCCF_PROGRAM_NOT_AVAILABLE      )
    PRINTREAS(MQRCCF_PROGRAM_AUTH_FAILED        )
    PRINTREAS(MQRCCF_NONE_FOUND                 )
    PRINTREAS(MQRCCF_SECURITY_SWITCH_OFF        )
    PRINTREAS(MQRCCF_SECURITY_REFRESH_FAILED    )
    PRINTREAS(MQRCCF_PARM_CONFLICT              )
    PRINTREAS(MQRCCF_COMMAND_INHIBITED          )
    PRINTREAS(MQRCCF_OBJECT_BEING_DELETED       )
    PRINTREAS(MQRCCF_STORAGE_CLASS_IN_USE       )
    PRINTREAS(MQRCCF_OBJECT_NAME_RESTRICTED     )
    PRINTREAS(MQRCCF_OBJECT_LIMIT_EXCEEDED      )
    PRINTREAS(MQRCCF_OBJECT_OPEN_FORCE          )
    PRINTREAS(MQRCCF_DISPOSITION_CONFLICT       )
    PRINTREAS(MQRCCF_Q_MGR_NOT_IN_QSG           )
    PRINTREAS(MQRCCF_ATTR_VALUE_FIXED           )
    PRINTREAS(MQRCCF_NAMELIST_ERROR             )
    PRINTREAS(MQRCCF_NO_CHANNEL_INITIATOR       )
    PRINTREAS(MQRCCF_CHANNEL_INITIATOR_ERROR    )
    PRINTREAS(MQRCCF_COMMAND_LEVEL_CONFLICT     )
    PRINTREAS(MQRCCF_Q_ATTR_CONFLICT            )
    PRINTREAS(MQRCCF_EVENTS_DISABLED            )
    PRINTREAS(MQRCCF_COMMAND_SCOPE_ERROR        )
    PRINTREAS(MQRCCF_COMMAND_REPLY_ERROR        )
    PRINTREAS(MQRCCF_FUNCTION_RESTRICTED        )
    PRINTREAS(MQRCCF_PARM_MISSING               )
    PRINTREAS(MQRCCF_PARM_VALUE_ERROR           )
    PRINTREAS(MQRCCF_COMMAND_LENGTH_ERROR       )
    PRINTREAS(MQRCCF_COMMAND_ORIGIN_ERROR       )
    PRINTREAS(MQRCCF_LISTENER_CONFLICT          )
    PRINTREAS(MQRCCF_LISTENER_STARTED           )
    PRINTREAS(MQRCCF_LISTENER_STOPPED           )
    PRINTREAS(MQRCCF_CHANNEL_ERROR              )
    PRINTREAS(MQRCCF_CF_STRUC_ERROR             )
    PRINTREAS(MQRCCF_UNKNOWN_USER_ID            )
    PRINTREAS(MQRCCF_UNEXPECTED_ERROR           )
    PRINTREAS(MQRCCF_NO_XCF_PARTNER             )
    PRINTREAS(MQRCCF_CFGR_PARM_ID_ERROR         )
    PRINTREAS(MQRCCF_CFIF_LENGTH_ERROR          )
    PRINTREAS(MQRCCF_CFIF_OPERATOR_ERROR        )
    PRINTREAS(MQRCCF_CFIF_PARM_ID_ERROR         )
    PRINTREAS(MQRCCF_CFSF_FILTER_VAL_LEN_ERR    )
    PRINTREAS(MQRCCF_CFSF_LENGTH_ERROR          )
    PRINTREAS(MQRCCF_CFSF_OPERATOR_ERROR        )
    PRINTREAS(MQRCCF_CFSF_PARM_ID_ERROR         )
    PRINTREAS(MQRCCF_TOO_MANY_FILTERS           )
    PRINTREAS(MQRCCF_LISTENER_RUNNING           )
    PRINTREAS(MQRCCF_LSTR_STATUS_NOT_FOUND      )
    PRINTREAS(MQRCCF_SERVICE_RUNNING            )
    PRINTREAS(MQRCCF_SERV_STATUS_NOT_FOUND      )
    PRINTREAS(MQRCCF_SERVICE_STOPPED            )
    PRINTREAS(MQRCCF_CFBS_DUPLICATE_PARM        )
    PRINTREAS(MQRCCF_CFBS_LENGTH_ERROR          )
    PRINTREAS(MQRCCF_CFBS_PARM_ID_ERROR         )
    PRINTREAS(MQRCCF_CFBS_STRING_LENGTH_ERR     )
    PRINTREAS(MQRCCF_CFGR_LENGTH_ERROR          )
    PRINTREAS(MQRCCF_CFGR_PARM_COUNT_ERROR      )
    PRINTREAS(MQRCCF_CONN_NOT_STOPPED           )
    PRINTREAS(MQRCCF_SERVICE_REQUEST_PENDING    )
    PRINTREAS(MQRCCF_NO_START_CMD               )
    PRINTREAS(MQRCCF_NO_STOP_CMD                )
    PRINTREAS(MQRCCF_CFBF_LENGTH_ERROR          )
    PRINTREAS(MQRCCF_CFBF_PARM_ID_ERROR         )
    PRINTREAS(MQRCCF_CFBF_OPERATOR_ERROR        )
    PRINTREAS(MQRCCF_CFBF_FILTER_VAL_LEN_ERR    )
    PRINTREAS(MQRCCF_LISTENER_STILL_ACTIVE      )
    PRINTREAS(MQRCCF_OBJECT_ALREADY_EXISTS      )
    PRINTREAS(MQRCCF_OBJECT_WRONG_TYPE          )
    PRINTREAS(MQRCCF_LIKE_OBJECT_WRONG_TYPE     )
    PRINTREAS(MQRCCF_OBJECT_OPEN                )
    PRINTREAS(MQRCCF_ATTR_VALUE_ERROR           )
    PRINTREAS(MQRCCF_UNKNOWN_Q_MGR              )
    PRINTREAS(MQRCCF_Q_WRONG_TYPE               )
    PRINTREAS(MQRCCF_OBJECT_NAME_ERROR          )
    PRINTREAS(MQRCCF_ALLOCATE_FAILED            )
    PRINTREAS(MQRCCF_HOST_NOT_AVAILABLE         )
    PRINTREAS(MQRCCF_CONFIGURATION_ERROR        )
    PRINTREAS(MQRCCF_CONNECTION_REFUSED         )
    PRINTREAS(MQRCCF_ENTRY_ERROR                )
    PRINTREAS(MQRCCF_SEND_FAILED                )
    PRINTREAS(MQRCCF_RECEIVED_DATA_ERROR        )
    PRINTREAS(MQRCCF_RECEIVE_FAILED             )
    PRINTREAS(MQRCCF_CONNECTION_CLOSED          )
    PRINTREAS(MQRCCF_NO_STORAGE                 )
    PRINTREAS(MQRCCF_NO_COMMS_MANAGER           )
    PRINTREAS(MQRCCF_LISTENER_NOT_STARTED       )
    PRINTREAS(MQRCCF_BIND_FAILED                )
    PRINTREAS(MQRCCF_CHANNEL_INDOUBT            )
    PRINTREAS(MQRCCF_MQCONN_FAILED              )
    PRINTREAS(MQRCCF_MQOPEN_FAILED              )
    PRINTREAS(MQRCCF_MQGET_FAILED               )
    PRINTREAS(MQRCCF_MQPUT_FAILED               )
    PRINTREAS(MQRCCF_PING_ERROR                 )
    PRINTREAS(MQRCCF_CHANNEL_IN_USE             )
    PRINTREAS(MQRCCF_CHANNEL_NOT_FOUND          )
    PRINTREAS(MQRCCF_UNKNOWN_REMOTE_CHANNEL     )
    PRINTREAS(MQRCCF_REMOTE_QM_UNAVAILABLE      )
    PRINTREAS(MQRCCF_REMOTE_QM_TERMINATING      )
    PRINTREAS(MQRCCF_MQINQ_FAILED               )
    PRINTREAS(MQRCCF_NOT_XMIT_Q                 )
    PRINTREAS(MQRCCF_CHANNEL_DISABLED           )
    PRINTREAS(MQRCCF_USER_EXIT_NOT_AVAILABLE    )
    PRINTREAS(MQRCCF_COMMIT_FAILED              )
    PRINTREAS(MQRCCF_WRONG_CHANNEL_TYPE         )
    PRINTREAS(MQRCCF_CHANNEL_ALREADY_EXISTS     )
    PRINTREAS(MQRCCF_DATA_TOO_LARGE             )
    PRINTREAS(MQRCCF_CHANNEL_NAME_ERROR         )
    PRINTREAS(MQRCCF_XMIT_Q_NAME_ERROR          )
    PRINTREAS(MQRCCF_MCA_NAME_ERROR             )
    PRINTREAS(MQRCCF_SEND_EXIT_NAME_ERROR       )
    PRINTREAS(MQRCCF_SEC_EXIT_NAME_ERROR        )
    PRINTREAS(MQRCCF_MSG_EXIT_NAME_ERROR        )
    PRINTREAS(MQRCCF_RCV_EXIT_NAME_ERROR        )
    PRINTREAS(MQRCCF_XMIT_Q_NAME_WRONG_TYPE     )
    PRINTREAS(MQRCCF_MCA_NAME_WRONG_TYPE        )
    PRINTREAS(MQRCCF_DISC_INT_WRONG_TYPE        )
    PRINTREAS(MQRCCF_SHORT_RETRY_WRONG_TYPE     )
    PRINTREAS(MQRCCF_SHORT_TIMER_WRONG_TYPE     )
    PRINTREAS(MQRCCF_LONG_RETRY_WRONG_TYPE      )
    PRINTREAS(MQRCCF_LONG_TIMER_WRONG_TYPE      )
    PRINTREAS(MQRCCF_PUT_AUTH_WRONG_TYPE        )
    PRINTREAS(MQRCCF_KEEP_ALIVE_INT_ERROR       )
    PRINTREAS(MQRCCF_MISSING_CONN_NAME          )
    PRINTREAS(MQRCCF_CONN_NAME_ERROR            )
    PRINTREAS(MQRCCF_MQSET_FAILED               )
    PRINTREAS(MQRCCF_CHANNEL_NOT_ACTIVE         )
    PRINTREAS(MQRCCF_TERMINATED_BY_SEC_EXIT     )
    PRINTREAS(MQRCCF_DYNAMIC_Q_SCOPE_ERROR      )
    PRINTREAS(MQRCCF_CELL_DIR_NOT_AVAILABLE     )
    PRINTREAS(MQRCCF_MR_COUNT_ERROR             )
    PRINTREAS(MQRCCF_MR_COUNT_WRONG_TYPE        )
    PRINTREAS(MQRCCF_MR_EXIT_NAME_ERROR         )
    PRINTREAS(MQRCCF_MR_EXIT_NAME_WRONG_TYPE    )
    PRINTREAS(MQRCCF_MR_INTERVAL_ERROR          )
    PRINTREAS(MQRCCF_MR_INTERVAL_WRONG_TYPE     )
    PRINTREAS(MQRCCF_NPM_SPEED_ERROR            )
    PRINTREAS(MQRCCF_NPM_SPEED_WRONG_TYPE       )
    PRINTREAS(MQRCCF_HB_INTERVAL_ERROR          )
    PRINTREAS(MQRCCF_HB_INTERVAL_WRONG_TYPE     )
    PRINTREAS(MQRCCF_CHAD_ERROR                 )
    PRINTREAS(MQRCCF_CHAD_WRONG_TYPE            )
    PRINTREAS(MQRCCF_CHAD_EVENT_ERROR           )
    PRINTREAS(MQRCCF_CHAD_EVENT_WRONG_TYPE      )
    PRINTREAS(MQRCCF_CHAD_EXIT_ERROR            )
    PRINTREAS(MQRCCF_CHAD_EXIT_WRONG_TYPE       )
    PRINTREAS(MQRCCF_SUPPRESSED_BY_EXIT         )
    PRINTREAS(MQRCCF_BATCH_INT_ERROR            )
    PRINTREAS(MQRCCF_BATCH_INT_WRONG_TYPE       )
    PRINTREAS(MQRCCF_NET_PRIORITY_ERROR         )
    PRINTREAS(MQRCCF_NET_PRIORITY_WRONG_TYPE    )
    PRINTREAS(MQRCCF_CHANNEL_CLOSED             )
    PRINTREAS(MQRCCF_Q_STATUS_NOT_FOUND         )
    PRINTREAS(MQRCCF_SSL_CIPHER_SPEC_ERROR      )
    PRINTREAS(MQRCCF_SSL_PEER_NAME_ERROR        )
    PRINTREAS(MQRCCF_SSL_CLIENT_AUTH_ERROR      )
    PRINTREAS(MQRCCF_RETAINED_NOT_SUPPORTED     )
    PRINTREAS(MQRC_NONE                      )
    PRINTREAS(MQRC_ALIAS_BASE_Q_TYPE_ERROR   )
    PRINTREAS(MQRC_ALREADY_CONNECTED         )
    PRINTREAS(MQRC_BACKED_OUT                )
    PRINTREAS(MQRC_BUFFER_ERROR              )
    PRINTREAS(MQRC_BUFFER_LENGTH_ERROR       )
    PRINTREAS(MQRC_CHAR_ATTR_LENGTH_ERROR    )
    PRINTREAS(MQRC_CHAR_ATTRS_ERROR          )
    PRINTREAS(MQRC_CHAR_ATTRS_TOO_SHORT      )
    PRINTREAS(MQRC_CONNECTION_BROKEN         )
    PRINTREAS(MQRC_DATA_LENGTH_ERROR         )
    PRINTREAS(MQRC_DYNAMIC_Q_NAME_ERROR      )
    PRINTREAS(MQRC_ENVIRONMENT_ERROR         )
    PRINTREAS(MQRC_EXPIRY_ERROR              )
    PRINTREAS(MQRC_FEEDBACK_ERROR            )
    PRINTREAS(MQRC_GET_INHIBITED             )
    PRINTREAS(MQRC_HANDLE_NOT_AVAILABLE      )
    PRINTREAS(MQRC_HCONN_ERROR               )
    PRINTREAS(MQRC_HOBJ_ERROR                )
    PRINTREAS(MQRC_INHIBIT_VALUE_ERROR       )
    PRINTREAS(MQRC_INT_ATTR_COUNT_ERROR      )
    PRINTREAS(MQRC_INT_ATTR_COUNT_TOO_SMALL  )
    PRINTREAS(MQRC_INT_ATTRS_ARRAY_ERROR     )
    PRINTREAS(MQRC_SYNCPOINT_LIMIT_REACHED   )
    PRINTREAS(MQRC_MAX_CONNS_LIMIT_REACHED   )
    PRINTREAS(MQRC_MD_ERROR                  )
    PRINTREAS(MQRC_MISSING_REPLY_TO_Q        )
    PRINTREAS(MQRC_MSG_TYPE_ERROR            )
    PRINTREAS(MQRC_MSG_TOO_BIG_FOR_Q         )
    PRINTREAS(MQRC_MSG_TOO_BIG_FOR_Q_MGR     )
    PRINTREAS(MQRC_NO_MSG_AVAILABLE          )
    PRINTREAS(MQRC_NO_MSG_UNDER_CURSOR       )
    PRINTREAS(MQRC_NOT_AUTHORIZED            )
    PRINTREAS(MQRC_NOT_OPEN_FOR_BROWSE       )
    PRINTREAS(MQRC_NOT_OPEN_FOR_INPUT        )
    PRINTREAS(MQRC_NOT_OPEN_FOR_INQUIRE      )
    PRINTREAS(MQRC_NOT_OPEN_FOR_OUTPUT       )
    PRINTREAS(MQRC_NOT_OPEN_FOR_SET          )
    PRINTREAS(MQRC_OBJECT_CHANGED            )
    PRINTREAS(MQRC_OBJECT_IN_USE             )
    PRINTREAS(MQRC_OBJECT_TYPE_ERROR         )
    PRINTREAS(MQRC_OD_ERROR                  )
    PRINTREAS(MQRC_OPTION_NOT_VALID_FOR_TYPE )
    PRINTREAS(MQRC_OPTIONS_ERROR             )
    PRINTREAS(MQRC_PERSISTENCE_ERROR         )
    PRINTREAS(MQRC_PERSISTENT_NOT_ALLOWED    )
    PRINTREAS(MQRC_PRIORITY_EXCEEDS_MAXIMUM  )
    PRINTREAS(MQRC_PRIORITY_ERROR            )
    PRINTREAS(MQRC_PUT_INHIBITED             )
    PRINTREAS(MQRC_Q_DELETED                 )
    PRINTREAS(MQRC_Q_FULL                    )
    PRINTREAS(MQRC_Q_NOT_EMPTY               )
    PRINTREAS(MQRC_Q_SPACE_NOT_AVAILABLE     )
    PRINTREAS(MQRC_Q_TYPE_ERROR              )
    PRINTREAS(MQRC_Q_MGR_NAME_ERROR          )
    PRINTREAS(MQRC_Q_MGR_NOT_AVAILABLE       )
    PRINTREAS(MQRC_REPORT_OPTIONS_ERROR      )
    PRINTREAS(MQRC_SECOND_MARK_NOT_ALLOWED   )
    PRINTREAS(MQRC_SECURITY_ERROR            )
    PRINTREAS(MQRC_SELECTOR_COUNT_ERROR      )
    PRINTREAS(MQRC_SELECTOR_LIMIT_EXCEEDED   )
    PRINTREAS(MQRC_SELECTOR_ERROR            )
    PRINTREAS(MQRC_SELECTOR_NOT_FOR_TYPE     )
    PRINTREAS(MQRC_SIGNAL_OUTSTANDING        )
    PRINTREAS(MQRC_SIGNAL_REQUEST_ACCEPTED   )
    PRINTREAS(MQRC_STORAGE_NOT_AVAILABLE     )
    PRINTREAS(MQRC_SYNCPOINT_NOT_AVAILABLE   )
    PRINTREAS(MQRC_TRIGGER_CONTROL_ERROR     )
    PRINTREAS(MQRC_TRIGGER_DEPTH_ERROR       )
    PRINTREAS(MQRC_TRIGGER_MSG_PRIORITY_ERR  )
    PRINTREAS(MQRC_TRIGGER_TYPE_ERROR        )
    PRINTREAS(MQRC_TRUNCATED_MSG_ACCEPTED    )
    PRINTREAS(MQRC_TRUNCATED_MSG_FAILED      )
    PRINTREAS(MQRC_UNKNOWN_ALIAS_BASE_Q      )
    PRINTREAS(MQRC_UNKNOWN_OBJECT_NAME       )
    PRINTREAS(MQRC_UNKNOWN_OBJECT_Q_MGR      )
    PRINTREAS(MQRC_UNKNOWN_REMOTE_Q_MGR      )
    PRINTREAS(MQRC_WAIT_INTERVAL_ERROR       )
    PRINTREAS(MQRC_XMIT_Q_TYPE_ERROR         )
    PRINTREAS(MQRC_XMIT_Q_USAGE_ERROR        )
    PRINTREAS(MQRC_NOT_OPEN_FOR_PASS_ALL     )
    PRINTREAS(MQRC_NOT_OPEN_FOR_PASS_IDENT   )
    PRINTREAS(MQRC_NOT_OPEN_FOR_SET_ALL      )
    PRINTREAS(MQRC_NOT_OPEN_FOR_SET_IDENT    )
    PRINTREAS(MQRC_CONTEXT_HANDLE_ERROR      )
    PRINTREAS(MQRC_CONTEXT_NOT_AVAILABLE     )
    PRINTREAS(MQRC_SIGNAL1_ERROR             )
    PRINTREAS(MQRC_OBJECT_ALREADY_EXISTS     )
    PRINTREAS(MQRC_OBJECT_DAMAGED            )
    PRINTREAS(MQRC_RESOURCE_PROBLEM          )
    PRINTREAS(MQRC_ANOTHER_Q_MGR_CONNECTED   )
    PRINTREAS(MQRC_UNKNOWN_REPORT_OPTION     )
    PRINTREAS(MQRC_STORAGE_CLASS_ERROR       )
    PRINTREAS(MQRC_COD_NOT_VALID_FOR_XCF_Q   )
    PRINTREAS(MQRC_XWAIT_CANCELED            )
    PRINTREAS(MQRC_XWAIT_ERROR               )
    PRINTREAS(MQRC_SUPPRESSED_BY_EXIT        )
    PRINTREAS(MQRC_FORMAT_ERROR              )
    PRINTREAS(MQRC_SOURCE_CCSID_ERROR        )
    PRINTREAS(MQRC_SOURCE_INTEGER_ENC_ERROR  )
    PRINTREAS(MQRC_SOURCE_DECIMAL_ENC_ERROR  )
    PRINTREAS(MQRC_SOURCE_FLOAT_ENC_ERROR    )
    PRINTREAS(MQRC_TARGET_CCSID_ERROR        )
    PRINTREAS(MQRC_TARGET_INTEGER_ENC_ERROR  )
    PRINTREAS(MQRC_TARGET_DECIMAL_ENC_ERROR  )
    PRINTREAS(MQRC_TARGET_FLOAT_ENC_ERROR    )
    PRINTREAS(MQRC_NOT_CONVERTED             )
    PRINTREAS(MQRC_CONVERTED_MSG_TOO_BIG     )
    PRINTREAS(MQRC_NO_EXTERNAL_PARTICIPANTS  )
    PRINTREAS(MQRC_PARTICIPANT_NOT_AVAILABLE )
    PRINTREAS(MQRC_OUTCOME_MIXED             )
    PRINTREAS(MQRC_OUTCOME_PENDING           )
    PRINTREAS(MQRC_BRIDGE_STARTED            )
    PRINTREAS(MQRC_BRIDGE_STOPPED            )
    PRINTREAS(MQRC_ADAPTER_STORAGE_SHORTAGE  )
    PRINTREAS(MQRC_UOW_IN_PROGRESS           )
    PRINTREAS(MQRC_ADAPTER_CONN_LOAD_ERROR   )
    PRINTREAS(MQRC_ADAPTER_SERV_LOAD_ERROR   )
    PRINTREAS(MQRC_ADAPTER_DEFS_ERROR        )
    PRINTREAS(MQRC_ADAPTER_DEFS_LOAD_ERROR   )
    PRINTREAS(MQRC_ADAPTER_CONV_LOAD_ERROR   )
    PRINTREAS(MQRC_BO_ERROR                  )
    PRINTREAS(MQRC_DH_ERROR                  )
    PRINTREAS(MQRC_MULTIPLE_REASONS          )
    PRINTREAS(MQRC_OPEN_FAILED               )
    PRINTREAS(MQRC_ADAPTER_DISC_LOAD_ERROR   )
    PRINTREAS(MQRC_CNO_ERROR                 )
    PRINTREAS(MQRC_CICS_WAIT_FAILED          )
    PRINTREAS(MQRC_DLH_ERROR                 )
    PRINTREAS(MQRC_HEADER_ERROR              )
    PRINTREAS(MQRC_SOURCE_LENGTH_ERROR       )
    PRINTREAS(MQRC_TARGET_LENGTH_ERROR       )
    PRINTREAS(MQRC_SOURCE_BUFFER_ERROR       )
    PRINTREAS(MQRC_TARGET_BUFFER_ERROR       )
    PRINTREAS(MQRC_IIH_ERROR                 )
    PRINTREAS(MQRC_PCF_ERROR                 )
    PRINTREAS(MQRC_DBCS_ERROR                )
    PRINTREAS(MQRC_OBJECT_NAME_ERROR         )
    PRINTREAS(MQRC_OBJECT_Q_MGR_NAME_ERROR   )
    PRINTREAS(MQRC_RECS_PRESENT_ERROR        )
    PRINTREAS(MQRC_OBJECT_RECORDS_ERROR      )
    PRINTREAS(MQRC_RESPONSE_RECORDS_ERROR    )
    PRINTREAS(MQRC_ASID_MISMATCH             )
    PRINTREAS(MQRC_PMO_RECORD_FLAGS_ERROR    )
    PRINTREAS(MQRC_PUT_MSG_RECORDS_ERROR     )
    PRINTREAS(MQRC_CONN_ID_IN_USE            )
    PRINTREAS(MQRC_Q_MGR_QUIESCING           )
    PRINTREAS(MQRC_Q_MGR_STOPPING            )
    PRINTREAS(MQRC_DUPLICATE_RECOV_COORD     )
    PRINTREAS(MQRC_PMO_ERROR                 )
    PRINTREAS(MQRC_API_EXIT_NOT_FOUND        )
    PRINTREAS(MQRC_API_EXIT_LOAD_ERROR       )
    PRINTREAS(MQRC_REMOTE_Q_NAME_ERROR       )
    PRINTREAS(MQRC_INCONSISTENT_PERSISTENCE  )
    PRINTREAS(MQRC_GMO_ERROR                 )
    PRINTREAS(MQRC_CICS_BRIDGE_RESTRICTION   )
    PRINTREAS(MQRC_STOPPED_BY_CLUSTER_EXIT   )
    PRINTREAS(MQRC_CLUSTER_RESOLUTION_ERROR  )
    PRINTREAS(MQRC_CONVERTED_STRING_TOO_BIG  )
    PRINTREAS(MQRC_TMC_ERROR                 )
    PRINTREAS(MQRC_STORAGE_MEDIUM_FULL       )
    PRINTREAS(MQRC_PAGESET_ERROR             )
    PRINTREAS(MQRC_NAME_NOT_VALID_FOR_TYPE   )
    PRINTREAS(MQRC_UNEXPECTED_ERROR          )
    PRINTREAS(MQRC_UNKNOWN_XMIT_Q            )
    PRINTREAS(MQRC_UNKNOWN_DEF_XMIT_Q        )
    PRINTREAS(MQRC_DEF_XMIT_Q_TYPE_ERROR     )
    PRINTREAS(MQRC_DEF_XMIT_Q_USAGE_ERROR    )
    PRINTREAS(MQRC_NAME_IN_USE               )
    PRINTREAS(MQRC_CONNECTION_QUIESCING      )
    PRINTREAS(MQRC_CONNECTION_STOPPING       )
    PRINTREAS(MQRC_ADAPTER_NOT_AVAILABLE     )
    PRINTREAS(MQRC_MSG_ID_ERROR              )
    PRINTREAS(MQRC_CORREL_ID_ERROR           )
    PRINTREAS(MQRC_FILE_SYSTEM_ERROR         )
    PRINTREAS(MQRC_NO_MSG_LOCKED             )
    PRINTREAS(MQRC_SOAP_DOTNET_ERROR         )
    PRINTREAS(MQRC_SOAP_AXIS_ERROR           )
    PRINTREAS(MQRC_SOAP_URL_ERROR            )
    PRINTREAS(MQRC_FILE_NOT_AUDITED          )
    PRINTREAS(MQRC_CONNECTION_NOT_AUTHORIZED )
    PRINTREAS(MQRC_MSG_TOO_BIG_FOR_CHANNEL   )
    PRINTREAS(MQRC_CALL_IN_PROGRESS          )
    PRINTREAS(MQRC_RMH_ERROR                 )
    PRINTREAS(MQRC_Q_MGR_ACTIVE              )
    PRINTREAS(MQRC_Q_MGR_NOT_ACTIVE          )
    PRINTREAS(MQRC_Q_DEPTH_HIGH              )
    PRINTREAS(MQRC_Q_DEPTH_LOW               )
    PRINTREAS(MQRC_Q_SERVICE_INTERVAL_HIGH   )
    PRINTREAS(MQRC_Q_SERVICE_INTERVAL_OK     )
    PRINTREAS(MQRC_RFH_HEADER_FIELD_ERROR    )
    PRINTREAS(MQRC_RAS_PROPERTY_ERROR        )
    PRINTREAS(MQRC_UNIT_OF_WORK_NOT_STARTED  )
    PRINTREAS(MQRC_CHANNEL_AUTO_DEF_OK       )
    PRINTREAS(MQRC_CHANNEL_AUTO_DEF_ERROR    )
    PRINTREAS(MQRC_CFH_ERROR                 )
    PRINTREAS(MQRC_CFIL_ERROR                )
    PRINTREAS(MQRC_CFIN_ERROR                )
    PRINTREAS(MQRC_CFSL_ERROR                )
    PRINTREAS(MQRC_CFST_ERROR                )
    PRINTREAS(MQRC_INCOMPLETE_GROUP          )
    PRINTREAS(MQRC_INCOMPLETE_MSG            )
    PRINTREAS(MQRC_INCONSISTENT_CCSIDS       )
    PRINTREAS(MQRC_INCONSISTENT_ENCODINGS    )
    PRINTREAS(MQRC_INCONSISTENT_UOW          )
    PRINTREAS(MQRC_INVALID_MSG_UNDER_CURSOR  )
    PRINTREAS(MQRC_MATCH_OPTIONS_ERROR       )
    PRINTREAS(MQRC_MDE_ERROR                 )
    PRINTREAS(MQRC_MSG_FLAGS_ERROR           )
    PRINTREAS(MQRC_MSG_SEQ_NUMBER_ERROR      )
    PRINTREAS(MQRC_OFFSET_ERROR              )
    PRINTREAS(MQRC_ORIGINAL_LENGTH_ERROR     )
    PRINTREAS(MQRC_SEGMENT_LENGTH_ZERO       )
    PRINTREAS(MQRC_UOW_NOT_AVAILABLE         )
    PRINTREAS(MQRC_WRONG_GMO_VERSION         )
    PRINTREAS(MQRC_WRONG_MD_VERSION          )
    PRINTREAS(MQRC_GROUP_ID_ERROR            )
    PRINTREAS(MQRC_INCONSISTENT_BROWSE       )
    PRINTREAS(MQRC_XQH_ERROR                 )
    PRINTREAS(MQRC_SRC_ENV_ERROR             )
    PRINTREAS(MQRC_SRC_NAME_ERROR            )
    PRINTREAS(MQRC_DEST_ENV_ERROR            )
    PRINTREAS(MQRC_DEST_NAME_ERROR           )
    PRINTREAS(MQRC_TM_ERROR                  )
    PRINTREAS(MQRC_CLUSTER_EXIT_ERROR        )
    PRINTREAS(MQRC_CLUSTER_EXIT_LOAD_ERROR   )
    PRINTREAS(MQRC_CLUSTER_PUT_INHIBITED     )
    PRINTREAS(MQRC_CLUSTER_RESOURCE_ERROR    )
    PRINTREAS(MQRC_NO_DESTINATIONS_AVAILABLE )
    PRINTREAS(MQRC_CONN_TAG_IN_USE           )
    PRINTREAS(MQRC_PARTIALLY_CONVERTED       )
    PRINTREAS(MQRC_CONNECTION_ERROR          )
    PRINTREAS(MQRC_OPTION_ENVIRONMENT_ERROR  )
    PRINTREAS(MQRC_CD_ERROR                  )
    PRINTREAS(MQRC_CLIENT_CONN_ERROR         )
    PRINTREAS(MQRC_CHANNEL_STOPPED_BY_USER   )
    PRINTREAS(MQRC_HCONFIG_ERROR             )
    PRINTREAS(MQRC_FUNCTION_ERROR            )
    PRINTREAS(MQRC_CHANNEL_STARTED           )
    PRINTREAS(MQRC_CHANNEL_STOPPED           )
    PRINTREAS(MQRC_CHANNEL_CONV_ERROR        )
    PRINTREAS(MQRC_SERVICE_NOT_AVAILABLE     )
    PRINTREAS(MQRC_INITIALIZATION_FAILED     )
    PRINTREAS(MQRC_TERMINATION_FAILED        )
    PRINTREAS(MQRC_UNKNOWN_Q_NAME            )
    PRINTREAS(MQRC_SERVICE_ERROR             )
    PRINTREAS(MQRC_Q_ALREADY_EXISTS          )
    PRINTREAS(MQRC_USER_ID_NOT_AVAILABLE     )
    PRINTREAS(MQRC_UNKNOWN_ENTITY            )
    PRINTREAS(MQRC_UNKNOWN_AUTH_ENTITY       )
    PRINTREAS(MQRC_UNKNOWN_REF_OBJECT        )
    PRINTREAS(MQRC_CHANNEL_ACTIVATED         )
    PRINTREAS(MQRC_CHANNEL_NOT_ACTIVATED     )
    PRINTREAS(MQRC_UOW_CANCELED              )
    PRINTREAS(MQRC_FUNCTION_NOT_SUPPORTED    )
    PRINTREAS(MQRC_SELECTOR_TYPE_ERROR       )
    PRINTREAS(MQRC_COMMAND_TYPE_ERROR        )
    PRINTREAS(MQRC_MULTIPLE_INSTANCE_ERROR   )
    PRINTREAS(MQRC_SYSTEM_ITEM_NOT_ALTERABLE )
    PRINTREAS(MQRC_BAG_CONVERSION_ERROR      )
    PRINTREAS(MQRC_SELECTOR_OUT_OF_RANGE     )
    PRINTREAS(MQRC_SELECTOR_NOT_UNIQUE       )
    PRINTREAS(MQRC_INDEX_NOT_PRESENT         )
    PRINTREAS(MQRC_STRING_ERROR              )
    PRINTREAS(MQRC_ENCODING_NOT_SUPPORTED    )
    PRINTREAS(MQRC_SELECTOR_NOT_PRESENT      )
    PRINTREAS(MQRC_OUT_SELECTOR_ERROR        )
    PRINTREAS(MQRC_STRING_TRUNCATED          )
    PRINTREAS(MQRC_SELECTOR_WRONG_TYPE       )
    PRINTREAS(MQRC_INCONSISTENT_ITEM_TYPE    )
    PRINTREAS(MQRC_INDEX_ERROR               )
    PRINTREAS(MQRC_SYSTEM_BAG_NOT_ALTERABLE  )
    PRINTREAS(MQRC_ITEM_COUNT_ERROR          )
    PRINTREAS(MQRC_FORMAT_NOT_SUPPORTED      )
    PRINTREAS(MQRC_SELECTOR_NOT_SUPPORTED    )
    PRINTREAS(MQRC_ITEM_VALUE_ERROR          )
    PRINTREAS(MQRC_HBAG_ERROR                )
    PRINTREAS(MQRC_PARAMETER_MISSING         )
    PRINTREAS(MQRC_CMD_SERVER_NOT_AVAILABLE  )
    PRINTREAS(MQRC_STRING_LENGTH_ERROR       )
    PRINTREAS(MQRC_INQUIRY_COMMAND_ERROR     )
    PRINTREAS(MQRC_NESTED_BAG_NOT_SUPPORTED  )
    PRINTREAS(MQRC_BAG_WRONG_TYPE            )
    PRINTREAS(MQRC_ITEM_TYPE_ERROR           )
    PRINTREAS(MQRC_SYSTEM_BAG_NOT_DELETABLE  )
    PRINTREAS(MQRC_SYSTEM_ITEM_NOT_DELETABLE )
    PRINTREAS(MQRC_CODED_CHAR_SET_ID_ERROR   )
    PRINTREAS(MQRC_MSG_TOKEN_ERROR           )
    PRINTREAS(MQRC_MISSING_WIH               )
    PRINTREAS(MQRC_WIH_ERROR                 )
    PRINTREAS(MQRC_RFH_ERROR                 )
    PRINTREAS(MQRC_RFH_STRING_ERROR          )
    PRINTREAS(MQRC_RFH_COMMAND_ERROR         )
    PRINTREAS(MQRC_RFH_PARM_ERROR            )
    PRINTREAS(MQRC_RFH_DUPLICATE_PARM        )
    PRINTREAS(MQRC_RFH_PARM_MISSING          )
    PRINTREAS(MQRC_CHAR_CONVERSION_ERROR     )
    PRINTREAS(MQRC_UCS2_CONVERSION_ERROR     )
    PRINTREAS(MQRC_DB2_NOT_AVAILABLE         )
    PRINTREAS(MQRC_OBJECT_NOT_UNIQUE         )
    PRINTREAS(MQRC_CONN_TAG_NOT_RELEASED     )
    PRINTREAS(MQRC_CF_NOT_AVAILABLE          )
    PRINTREAS(MQRC_CF_STRUC_IN_USE           )
    PRINTREAS(MQRC_CF_STRUC_LIST_HDR_IN_USE  )
    PRINTREAS(MQRC_CF_STRUC_AUTH_FAILED      )
    PRINTREAS(MQRC_CF_STRUC_ERROR            )
    PRINTREAS(MQRC_CONN_TAG_NOT_USABLE       )
    PRINTREAS(MQRC_GLOBAL_UOW_CONFLICT       )
    PRINTREAS(MQRC_LOCAL_UOW_CONFLICT        )
    PRINTREAS(MQRC_HANDLE_IN_USE_FOR_UOW     )
    PRINTREAS(MQRC_UOW_ENLISTMENT_ERROR      )
    PRINTREAS(MQRC_UOW_MIX_NOT_SUPPORTED     )
    PRINTREAS(MQRC_WXP_ERROR                 )
    PRINTREAS(MQRC_CURRENT_RECORD_ERROR      )
    PRINTREAS(MQRC_NEXT_OFFSET_ERROR         )
    PRINTREAS(MQRC_NO_RECORD_AVAILABLE       )
    PRINTREAS(MQRC_OBJECT_LEVEL_INCOMPATIBLE )
    PRINTREAS(MQRC_NEXT_RECORD_ERROR         )
    PRINTREAS(MQRC_BACKOUT_THRESHOLD_REACHED )
    PRINTREAS(MQRC_MSG_NOT_MATCHED           )
    PRINTREAS(MQRC_JMS_FORMAT_ERROR          )
    PRINTREAS(MQRC_SEGMENTS_NOT_SUPPORTED    )
    PRINTREAS(MQRC_WRONG_CF_LEVEL            )
    PRINTREAS(MQRC_CONFIG_CREATE_OBJECT      )
    PRINTREAS(MQRC_CONFIG_CHANGE_OBJECT      )
    PRINTREAS(MQRC_CONFIG_DELETE_OBJECT      )
    PRINTREAS(MQRC_CONFIG_REFRESH_OBJECT     )
    PRINTREAS(MQRC_CHANNEL_SSL_ERROR         )
    PRINTREAS(MQRC_CF_STRUC_FAILED           )
    PRINTREAS(MQRC_API_EXIT_ERROR            )
    PRINTREAS(MQRC_API_EXIT_INIT_ERROR       )
    PRINTREAS(MQRC_API_EXIT_TERM_ERROR       )
    PRINTREAS(MQRC_EXIT_REASON_ERROR         )
    PRINTREAS(MQRC_RESERVED_VALUE_ERROR      )
    PRINTREAS(MQRC_NO_DATA_AVAILABLE         )
    PRINTREAS(MQRC_SCO_ERROR                 )
    PRINTREAS(MQRC_KEY_REPOSITORY_ERROR      )
    PRINTREAS(MQRC_CRYPTO_HARDWARE_ERROR     )
    PRINTREAS(MQRC_AUTH_INFO_REC_COUNT_ERROR )
    PRINTREAS(MQRC_AUTH_INFO_REC_ERROR       )
    PRINTREAS(MQRC_AIR_ERROR                 )
    PRINTREAS(MQRC_AUTH_INFO_TYPE_ERROR      )
    PRINTREAS(MQRC_AUTH_INFO_CONN_NAME_ERROR )
    PRINTREAS(MQRC_LDAP_USER_NAME_ERROR      )
    PRINTREAS(MQRC_LDAP_USER_NAME_LENGTH_ERR )
    PRINTREAS(MQRC_LDAP_PASSWORD_ERROR       )
    PRINTREAS(MQRC_SSL_ALREADY_INITIALIZED   )
    PRINTREAS(MQRC_SSL_CONFIG_ERROR          )
    PRINTREAS(MQRC_SSL_INITIALIZATION_ERROR  )
    PRINTREAS(MQRC_Q_INDEX_TYPE_ERROR        )
    PRINTREAS(MQRC_CFBS_ERROR                )
    PRINTREAS(MQRC_SSL_NOT_ALLOWED           )
    PRINTREAS(MQRC_JSSE_ERROR                )
    PRINTREAS(MQRC_SSL_PEER_NAME_MISMATCH    )
    PRINTREAS(MQRC_SSL_PEER_NAME_ERROR       )
    PRINTREAS(MQRC_UNSUPPORTED_CIPHER_SUITE  )
    PRINTREAS(MQRC_SSL_CERTIFICATE_REVOKED   )
    PRINTREAS(MQRC_SSL_CERT_STORE_ERROR      )
    PRINTREAS(MQRC_CLIENT_EXIT_LOAD_ERROR    )
    PRINTREAS(MQRC_CLIENT_EXIT_ERROR         )
    PRINTREAS(MQRC_SSL_KEY_RESET_ERROR       )
    PRINTREAS(MQRC_UNKNOWN_COMPONENT_NAME    )
    PRINTREAS(MQRC_LOGGER_STATUS             )
    PRINTREAS(MQRC_COMMAND_MQSC              )
    PRINTREAS(MQRC_COMMAND_PCF               )
    PRINTREAS(MQRC_CFIF_ERROR                )
    PRINTREAS(MQRC_CFSF_ERROR                )
    PRINTREAS(MQRC_CFGR_ERROR                )
    PRINTREAS(MQRC_MSG_NOT_ALLOWED_IN_GROUP  )
    PRINTREAS(MQRC_FILTER_OPERATOR_ERROR     )
    PRINTREAS(MQRC_NESTED_SELECTOR_ERROR     )
    PRINTREAS(MQRC_EPH_ERROR                 )
    PRINTREAS(MQRC_RFH_FORMAT_ERROR          )
    PRINTREAS(MQRC_CFBF_ERROR                )
    PRINTREAS(MQRC_CLIENT_CHANNEL_CONFLICT   )
    PRINTREAS(MQRC_REOPEN_EXCL_INPUT_ERROR   )
    PRINTREAS(MQRC_REOPEN_INQUIRE_ERROR      )
    PRINTREAS(MQRC_REOPEN_SAVED_CONTEXT_ERR  )
    PRINTREAS(MQRC_REOPEN_TEMPORARY_Q_ERROR  )
    PRINTREAS(MQRC_ATTRIBUTE_LOCKED          )
    PRINTREAS(MQRC_CURSOR_NOT_VALID          )
    PRINTREAS(MQRC_ENCODING_ERROR            )
    PRINTREAS(MQRC_STRUC_ID_ERROR            )
    PRINTREAS(MQRC_NULL_POINTER              )
    PRINTREAS(MQRC_NO_CONNECTION_REFERENCE   )
    PRINTREAS(MQRC_NO_BUFFER                 )
    PRINTREAS(MQRC_BINARY_DATA_LENGTH_ERROR  )
    PRINTREAS(MQRC_BUFFER_NOT_AUTOMATIC      )
    PRINTREAS(MQRC_INSUFFICIENT_BUFFER       )
    PRINTREAS(MQRC_INSUFFICIENT_DATA         )
    PRINTREAS(MQRC_DATA_TRUNCATED            )
    PRINTREAS(MQRC_ZERO_LENGTH               )
    PRINTREAS(MQRC_NEGATIVE_LENGTH           )
    PRINTREAS(MQRC_NEGATIVE_OFFSET           )
    PRINTREAS(MQRC_INCONSISTENT_FORMAT       )
    PRINTREAS(MQRC_INCONSISTENT_OBJECT_STATE )
    PRINTREAS(MQRC_CONTEXT_OBJECT_NOT_VALID  )
    PRINTREAS(MQRC_CONTEXT_OPEN_ERROR        )
    PRINTREAS(MQRC_STRUC_LENGTH_ERROR        )
    PRINTREAS(MQRC_NOT_CONNECTED             )
    PRINTREAS(MQRC_NOT_OPEN                  )
    PRINTREAS(MQRC_DISTRIBUTION_LIST_EMPTY   )
    PRINTREAS(MQRC_INCONSISTENT_OPEN_OPTIONS )
    PRINTREAS(MQRC_WRONG_VERSION             )
    PRINTREAS(MQRC_REFERENCE_ERROR           )
    default:
      printf("It's an unknown reason, %ld\n",
              reason);
      break;
  }
}
void rmvexpired(char * thequeue)
{
  /*******************************************************************/
  /* declare LOCAL variables                                         */
  /*******************************************************************/
  MQOD     od = {MQOD_DEFAULT};       /* Object Descriptor           */
  MQLONG   OpenCode;                  /* MQOPEN completion code      */
  MQHOBJ   Hobj;                      /* object handle               */
  MQLONG   CompCode;                  /* completion code             */
  MQLONG   Reason;                    /* reason code                 */
  MQGMO    gmo = {MQGMO_DEFAULT};     /* get message options         */
  MQMD     md = {MQMD_DEFAULT};       /* Message Descriptor          */
  MQLONG   outmsglen;                 /* message length received     */
  MQLONG   C_options;                 /* MQCLOSE options             */
  MQLONG   msgcount = 0;              /* msg counter                 */

  /*******************************************************************/
  /* Initialize object descriptor for subject queue                  */
  /*******************************************************************/
  strcpy(od.ObjectName, thequeue);

  /*******************************************************************/
  /* Open the queue for browse only. Use of the queue is controlled  */
  /* by the queue definition here                                    */
  /*******************************************************************/
  MQOPEN(Hcon,                        /* connection handle           */
         &od,                         /* object descriptor for queue */
         MQOO_FAIL_IF_QUIESCING
           + MQOO_BROWSE,             /* open options                */
         &Hobj,                       /* object handle               */
         &CompCode,                   /* completion code             */
         &Reason);                    /* reason code                 */

  /*******************************************************************/
  /* report reason, if any                                           */
  /*******************************************************************/
  if (Reason != MQRC_NONE)
  {
    printf("MQOPEN (%s) ==> %ld\n", od.ObjectName, Reason);
    printreas(Reason);
  }

  OpenCode = CompCode;                 /* keep for conditional close */

  /*******************************************************************/
  /* go through the whole queue browsing the messages                */
  /*******************************************************************/
  while (CompCode != MQCC_FAILED)
  {
    /*****************************************************************/
    /* We don't really need to get the message,just to touch it to   */
    /* make the expired flag take effect so don't need a big buffer  */
    /*****************************************************************/
    gmo.Options = MQGMO_NO_WAIT + MQGMO_BROWSE_NEXT
                                + MQGMO_ACCEPT_TRUNCATED_MSG;

    /*****************************************************************/
    /* clear selectors to get messages in sequence                   */
    /*****************************************************************/
    memcpy(md.MsgId, MQMI_NONE, sizeof(md.MsgId));
    memcpy(md.CorrelId, MQCI_NONE, sizeof(md.CorrelId));

    /*****************************************************************/
    /* browse the message                                            */
    /*****************************************************************/
    MQGET(Hcon,                        /* connection handle          */
          Hobj,                        /* object handle              */
          &md,                         /* message descriptor         */
          &gmo,                        /* get message options        */
          0,                           /* buffer length              */
          outmsg,                      /* outmsg message buffer      */
          &outmsglen,                  /* message length             */
          &CompCode,                   /* completion code            */
          &Reason);                    /* reason code                */

    /*****************************************************************/
    /* report reason, if any                                         */
    /*****************************************************************/
    if (Reason != MQRC_NONE && Reason != MQRC_TRUNCATED_MSG_ACCEPTED)
    {
      if (Reason != MQRC_NO_MSG_AVAILABLE)
      {
        printf("MQGET ==> %ld\n", Reason);
        printreas(Reason);
      }
    }
    else
    {
      msgcount++;
    }
  }                                    /* end msg processing loop    */
  if (Reason == MQRC_NO_MSG_AVAILABLE)
  {
    printf("%ld msgs on queue\n",msgcount);
  }

  /*******************************************************************/
  /* close the queue - if it was opened                              */
  /*******************************************************************/
  if (OpenCode != MQCC_FAILED)
  {
    C_options = 0;                   /* no close options             */
    MQCLOSE(Hcon,                    /* connection handle            */
           &Hobj,                    /* object handle                */
           C_options,
           &CompCode,                /* completion code              */
           &Reason);                 /* reason code                  */
    /*****************************************************************/
    /* report reason, if any                                         */
    /*****************************************************************/
    if (Reason != MQRC_NONE)
    {
      printf("MQCLOSE ==> %ld\n", Reason);
      printreas(Reason);
    }
  }
}
